@@ -27,7 +27,6 @@
 #include "testentry.h"
 
 
-class QTimer;
 class WordCount;
 
 
@@ -36,43 +35,15 @@ class Collection : public QObject
     Q_OBJECT
 
 public:
-    Collection(KEduVocDocument *doc, QObject* parent = 0);
     Collection(QUrl *url, QObject* parent = 0);
     ~Collection();
 
-
     KEduVocDocument *eduVocDocument();
-
-    void setTitle(const QString& title);
-
     void numDueWords(WordCount &wc);
 
-
-    /** Enable/disable the timed auto backup
-     */
-    void enableAutoBackup(bool enable);
-
-public Q_SLOTS:
-
-    /** close the document*/
-    void close();
-
-Q_SIGNALS:
-    /** Emitted when the document pointer is changed.
-     @todo Stop using documentChanged(0) as a replacement for destoyed in editor classes.**/
-    void documentChanged(KEduVocDocument *newDocument);
-    void languagesChanged();
-    void statesNeedSaving();
-
-private:
-    void initializeDefaultGrammar(KEduVocDocument *doc);
-    void setDefaultDocumentProperties(KEduVocDocument *doc);
-
  private:
     // The contents of the document
     KEduVocDocument *m_doc;
-
-    QTimer           *m_backupTimer; // Timer for next autosave
     QList<TestEntry*> m_allTestEntries;
 
 };
