@@ -22,6 +22,6 @@ public:
     GradeReferenceWidget(QWidget *parent = 0);
 
 protected:
-    void paintEvent(QPaintEvent *);
+    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
 
 };
