@@ -16,7 +16,7 @@
 
 #include "abstractfrontend.h"
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 class QVariant;
 
@@ -40,8 +40,8 @@ public:
     virtual void setFeedbackState(AbstractFrontend::ResultState feedbackState) = 0;
     virtual void setResultState(AbstractFrontend::ResultState resultState) = 0;
 
-    virtual void setQuestionSound(const KUrl& soundUrl) = 0;
-    virtual void setSolutionSound(const KUrl& soundUrl) = 0;
+    virtual void setQuestionSound(const QUrl& soundUrl) = 0;
+    virtual void setSolutionSound(const QUrl& soundUrl) = 0;
     virtual void setSolutionPronunciation(const QString& pronunciationText) = 0;
     virtual void setQuestionPronunciation(const QString& pronunciationText) = 0;
 
@@ -57,13 +57,6 @@ public slots:
     virtual void showSolution() = 0;
     virtual void showSynonym() = 0;
 
-    /** To be called prior to focus change in deletion to allow any cleanup.
-
-     @todo When frameworks/kde5 is implemented remove this code, if the bug
-     in Qt (returning a pointer to a deleted stylesheet) is fixed.
-     */
-    virtual void objectDestroyed(QObject *obj = 0);
-
 signals:
     void continueAction();
     void stopAudio();
