@@ -23,13 +23,15 @@ class ParleyDocument;
 
 namespace Practice
 {
-class TestEntryManager;
+class SessionManagerBase;
 
 class PracticeStateMachine : public QObject
 {
     Q_OBJECT
 public:
-    PracticeStateMachine(AbstractFrontend* frontend, ParleyDocument* doc, const PracticeOptions& options, TestEntryManager* testEntryManager,  QObject* parent = 0);
+    PracticeStateMachine(AbstractFrontend* frontend, ParleyDocument* doc,
+                         SessionManagerBase* sessionManager,
+                         QObject* parent = 0);
     void start();
 
 Q_SIGNALS:
@@ -70,9 +72,8 @@ private:
     AbstractFrontend* m_frontend;
     AbstractBackendMode* m_mode;
     ParleyDocument* m_document;
-    PracticeOptions m_options;
     TestEntry* m_current;
-    TestEntryManager* m_testEntryManager;
+    SessionManagerBase* m_sessionManager;
 };
 
 }
